==> tpcclib-0.7.8-src.tar.gz: v2/libtpcbfm/test_tpcbfm.h <==
#ifndef _TEST_TPCBFM_H_
#define _TEST_TPCBFM_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpcbfm.h"
/*****************************************************************************/

/*****************************************************************************/
/* test_bfm */
int create_inp(TAC *tac);
int create_tis(TAC *tac);
int create_ref(TAC *tac);
/*****************************************************************************/

/*****************************************************************************/
/* bf_dexp */
int test_spectralDExp(TPCSTATUS *status);
int test_spectralKRange(TPCSTATUS *status);
int test_spectralBFNr(TPCSTATUS *status);
int test_spectralBFExtract(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* bf_radiowater */
int test_bf_radiowater(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* bf_srtm */
int test_bf_srtm(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCBFM */

==> tpcclib-0.8.1-src.tar.gz: v2/libtpcbfm/test_tpcbfm.h <==
#ifndef _TEST_TPCBFM_H_
#define _TEST_TPCBFM_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpcbfm.h"
/*****************************************************************************/

/*****************************************************************************/
/* test_bfm */
int create_inp(TAC *tac);
int create_tis(TAC *tac);
int create_ref(TAC *tac);
/*****************************************************************************/

/*****************************************************************************/
/* bf_dexp */
int test_spectralDExp(TPCSTATUS *status);
int test_spectralKRange(TPCSTATUS *status);
int test_spectralBFNr(TPCSTATUS *status);
int test_spectralBFExtract(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* bf_1tcm */
int test_bf_1tcm(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* bf_srtm */
int test_bf_srtm(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCBFM */
